import {
  Component,
  EventEmitter,
  Input,
  OnInit,
  Output,
  ViewChild,
} from "@angular/core";
import { FormBuilder, FormGroup, Validators } from "@angular/forms";
import { NgbActiveModal } from "@ng-bootstrap/ng-bootstrap";
import { UploadImageComponent } from "app/upload-image/upload-image.component";
import { OngProject } from "../ong-project.model";

@Component({
  selector: "jhi-add-project-modal",
  templateUrl: "./add-project-modal.component.html",
  styleUrls: ["./add-project-modal.component.scss"],
})
export class AddProjectModalComponent implements OnInit {
  @Output() projectSaved = new EventEmitter<OngProject>();
  @Input() projectTitle = "";
  @Input() projectDescription = "";
  @Input() projectImagePath = "";
  @Input() id = "";
  @ViewChild("projectImageUploader", { static: false })
  projectImageUploader?: UploadImageComponent;

  projectForm?: FormGroup;
  currentPicturesList: string[] = [];
  constructor(private fb: FormBuilder, public activeModal: NgbActiveModal) {}

  ngOnInit(): void {
    this.projectForm = this.fb.group({
      projectTitle: [
        this.projectTitle,
        [Validators.required, Validators.maxLength(1500)],
      ],
      projectDescription: [
        this.projectDescription,
        [Validators.required,Validators.minLength(10), Validators.maxLength(1500)],
      ],
    });

    if (this.projectImagePath) {
      this.currentPicturesList = this.projectImagePath?.split(
        ",",
        this.projectImagePath.split(",").length - 1
      );
    }
  }

  async saveProject(): Promise<void> {
    const projectTitle = this.projectForm?.get("projectTitle")!.value;
    const projectDescription = this.projectForm?.get("projectDescription")!
      .value;
    let projectImagePath = (await this.projectImageUploader?.upload()) as string;
    const currentPicturePath = this.currentPicturesList?.join();

    if (projectImagePath) {
      projectImagePath = projectImagePath + currentPicturePath;
      if (!projectImagePath.endsWith(",")) {
        projectImagePath = projectImagePath + ",";
      }
    } else {
      projectImagePath = currentPicturePath;
      if (projectImagePath.length !== 0) {
        if (!projectImagePath.endsWith(",")) {
          projectImagePath = projectImagePath + ",";
        }
      }
    }

    if (this.id) {
      this.projectSaved.emit(
        new OngProject(
          projectTitle,
          projectDescription,
          projectImagePath,
          this.id
        )
      );
    } else {
      this.projectSaved.emit(
        new OngProject(projectTitle, projectDescription, projectImagePath)
      );
    }
  }

  removePicture(index: number): void {
    this.currentPicturesList = this.currentPicturesList
      ?.slice(0, index)
      .concat(this.currentPicturesList.slice(index + 1));
  }
}
