import { Component, OnInit, ViewChild } from "@angular/core";
import { FormBuilder, Validators } from "@angular/forms";
import { UploadImageComponent } from "app/upload-image/upload-image.component";
import { OngSettingsService } from "./ong-settings.service";
import { OngProject } from "./ong-project.model";
import { NgbModal, ModalDismissReasons } from "@ng-bootstrap/ng-bootstrap";
import { AddProjectModalComponent } from "./add-project-modal/add-project-modal.component";
import { OngSettings } from "./ong-settings.model";
import { SessionStorageService } from "ngx-webstorage";

@Component({
  selector: "jhi-ong-settings",
  templateUrl: "./ong-settings.component.html",
  styleUrls: ["./ong-settings.component.scss"],
})

export class OngSettingsComponent implements OnInit {
  
  ongAccount = false;
  success = false;
  maxUploadNr = 1;
  firstSettings = true;
 
  @ViewChild("coverUploader", { static: false })
  coverUploader?: UploadImageComponent;

  @ViewChild("logoUploader", { static: false })
  logoUploader?: UploadImageComponent;

  closeResult = "";
  urls = new Array<string>();

  existingProjectPicturesList: Map<string, string[]> = new Map();
  currentProjectPicturesList?: string[];
  projectPicturesList: string[] | undefined = [];
  projectPicture?: string;
  currentOngLogoPath?: string;
  currentOngCoverPath?: string;
  ongSocialLinks: string[] = [];
  pdfList: any[] = [];


  project = false;
  ongForm = this.fb.group({
    ongDescription: ["", [Validators.required, Validators.max(1500)]],
    contact: ["", [Validators.required, Validators.max(50)]],
    websiteLink: ["", [Validators.pattern("(https?://)?([\\da-z.-]+)\\.([a-z.]{2,6})[/\\w .-]*/?")]],
    socialLink: ["", [Validators.pattern("(https?://)?([\\da-z.-]+)\\.([a-z.]{2,6})[/\\w .-]*/?")]],
    ongNeeds: ""
  });

  currentSettings?: OngSettings;
  projectsList: OngProject[] = [];
  projectToEdit?: number;
  name?: string;
  companyName: string | undefined;
  fileToUpload?: File | null;

  constructor(
    private fb: FormBuilder,
    private ongSettingsService: OngSettingsService,
    private modalService: NgbModal,
    public $sessionStorage: SessionStorageService
  ) {}

  ngOnInit(): void {

    this.ongSettingsService.getSettings().subscribe((data) => {

      this.firstSettings = false;
      this.currentSettings = data;

      this.ongForm.patchValue({

        ongDescription: this.currentSettings.ongDescription,
        contact: this.currentSettings.contact,
        websiteLink: this.currentSettings.ongLink,
        ongNeeds: this.currentSettings.ongNeeds

      });

      this.projectsList = (this.currentSettings.ongProjects as OngProject[]) || [];
      this.ongSocialLinks = this.currentSettings.socialLinks!;

      this.currentOngLogoPath = this.currentSettings.ongLogoPath?.split(",")[0];
      this.currentOngCoverPath = this.currentSettings.ongCoverPath?.split(
        ","
      )[0];
      this.companyName = this.currentSettings.user?.company;
      if (this.currentSettings.user?.company != null) {
        this.ongAccount = true;
      }
    });
  }

  removeLogoPicture(): void {
    this.currentOngLogoPath = "";
  }

  removeCoverPicture(): void {
    this.currentOngCoverPath = "";
  }

  get isValid(): boolean {
    const fields = ["ongDescription", "contact", "socialLink", "websiteLink"];

    for (const field of fields) {
      const fieldControl = this.ongForm.get(field);
      if (fieldControl && fieldControl.invalid) {
        return false;
      }
    }
    return true;
  }

  async submitOngSettings(): Promise<void> {

    const ongDescription = this.ongForm.get(["ongDescription"])!.value;
    const contact = this.ongForm.get(["contact"])!.value;
    let ongLink = this.ongForm.get(["websiteLink"])!.value;
    const ongNeeds = this.ongForm.get(["ongNeeds"])!.value
    const socialLinks: string[] = this.ongSocialLinks;
    let ongLogoPath = "";
    let ongCoverPath = "";

    if (this.ongForm.get(["socialLink"])!.value !== "" && this.ongSocialLinks !== null && !this.ongForm.get('socialLink')?.invalid) {
      socialLinks.push(this.ongForm.get(["socialLink"])!.value)
    }

    if (!ongLink) {
      ongLink = "";
    }

    if (this.currentOngLogoPath === "") {
      ongLogoPath = (await this.logoUploader?.upload()) as string;
    } 

    else if (
      this.currentOngLogoPath !== "" &&
      (await this.logoUploader?.upload()) !== ""
    ) {
      ongLogoPath = (await this.logoUploader?.upload()) as string;
    } 

    else {
      ongLogoPath = this.currentOngLogoPath as string;
    }


    if (this.currentOngCoverPath === "") {
      ongCoverPath = (await this.coverUploader?.upload()) as string;
    } 
    
    else if (
      this.currentOngCoverPath !== "" &&
      (await this.coverUploader?.upload()) !== ""
    ) {
      ongCoverPath = (await this.coverUploader?.upload()) as string;
    } 
    
    
    else {
      ongCoverPath = this.currentOngCoverPath as string;
    }

    const ongProjects = this.projectsList;

    // post or edit settings request
    if (this.firstSettings === true) {

      this.ongSettingsService
        .saveSettings({
          ongNeeds,
          socialLinks,
          ongLink,
          ongDescription,
          contact,
          ongCoverPath,
          ongLogoPath,
          ongProjects,

        })
        .subscribe(() => {

          this.ongForm.reset();
          this.success = true;

        });
    }
    
    
    else {
      this.ongSettingsService
        .putSettings({
          ongNeeds,
          socialLinks,
          ongLink,
          ongDescription,
          contact,
          ongCoverPath,
          ongLogoPath,
          ongProjects,

        })
        .subscribe(() => {

          this.ongForm.reset();
          this.success = true;

        });
    }
  }

  removeProject(index: number): void {

    this.projectsList = this.projectsList.slice(0, index).concat(this.projectsList.slice(index + 1));

  }

  openProjectForm(projectIndex?: number): void {

    let project = null;

    if (!isNaN(projectIndex as number)) {

      project = this.projectsList[projectIndex as number];

      this.ongForm.get("project")?.setValue({
        projectTitle: project.projectTitle,
        projectDescription: project.projectDescription,
        currentPicturesList : project.projectImagePath
      });

    }


    const modal = this.modalService.open(AddProjectModalComponent, {

      ariaLabelledBy: "modal-basic-title",

    });

    Object.assign(modal.componentInstance, project);

    modal.componentInstance.projectSaved.subscribe((p: OngProject) => {

      this.modalService.dismissAll();

      if (isNaN(projectIndex as number)) {

        this.projectsList.push(p);

      } else {

        this.projectsList[projectIndex as number] = p;

      }


      const pathListLength = p.projectImagePath!.split(",").length - 1;
      this.currentProjectPicturesList = p.projectImagePath?.split(
        ",",
        pathListLength
      );

    });

    modal.result.then(

      (result) => {
        this.closeResult = `Closed with: ${result}`;
      },
      (reason) => {
        this.closeResult = `Dismissed ${this.getDismissReason(reason)}`;

      }
    );
  }

  private getDismissReason(reason: any): string {

    if (reason === ModalDismissReasons.ESC) {
      return "by pressing ESC";
    } else if (reason === ModalDismissReasons.BACKDROP_CLICK) {
      return "by clicking on a backdrop";
    } else {
      return `with: ${reason}`;
    }

  }

  goBack(): void {

    this.success = !this.success;
    this.ngOnInit();

  }

  addSocialLink(): void {
    const socialLink = this.ongForm.get(["socialLink"])!.value;
    if (!this.ongForm.get('socialLink')?.invalid) {
      if (socialLink !== "" && this.ongSocialLinks == null && socialLink != null) {
        this.ongSocialLinks = [];
        this.ongSocialLinks.push(socialLink);
        this.ongForm.get("socialLink")?.setValue("")
      } else if (socialLink !== "" && this.ongSocialLinks != null && socialLink != null) {
        this.ongSocialLinks.push(socialLink);
        this.ongForm.get("socialLink")?.setValue("")
      }
    }
  }

  removeSocialLink(index: number): void {

    this.ongSocialLinks = this.ongSocialLinks.slice(0, index).concat(this.ongSocialLinks.slice(index + 1))
    
  }

}
