import { Observable } from "rxjs";

import { Injectable } from "@angular/core";
import { HttpClient } from "@angular/common/http";

import { SERVER_API_URL } from "app/app.constants";
import { OngSettings } from "./ong-settings.model";


@Injectable({ providedIn: "root" })
export class OngSettingsService {

    constructor(private http: HttpClient) {
    }

    saveSettings(settings: OngSettings): Observable<OngSettings> {
       return this.http.post(SERVER_API_URL + 'api/ongProfile', settings);
    }

    getSettings(): Observable<OngSettings> {
      return this.http.get(SERVER_API_URL + 'api/ongProfile/myOngProfile')
    }

    putSettings( settings: OngSettings ): Observable<OngSettings>{
      return this.http.put(SERVER_API_URL + 'api/ongProfile', settings);
    }

    getImage(url:string): Observable<any> {
        return this.http.get<any>(url);
    }

    emailSubscribe(ongName: string): Observable<any>{
      return this.http.post(SERVER_API_URL + 'api/ongProfile/' + ongName + '/subscribe', ongName);
    }

    emailUnsubscribe(ongName: string): Observable<any>{
      return this.http.post(SERVER_API_URL + 'api/ongProfile/' + ongName + '/unsubscribe', ongName);
    }

    checkSubscription(ongName: string): Observable<any>{
      return this.http.get(SERVER_API_URL + 'api/ongProfile/' + ongName + '/checkIfSubscribed')
    }

    getOng(ongName: string): Observable<OngSettings>{
      return this.http.get(SERVER_API_URL + 'api/ongProfile/' + ongName);
    }
}

