import { HttpErrorResponse } from '@angular/common/http';
import { AfterViewInit, Component, ElementRef, ViewChild } from '@angular/core';
import { FormBuilder, Validators } from '@angular/forms';
import { LoginModalService } from 'app/core/login/login-modal.service';
import { EMAIL_ALREADY_USED_TYPE } from 'app/shared/constants/error.constants';
import { JhiLanguageService } from 'ng-jhipster';
import { RegisterService } from './register.service';



@Component({
  selector: 'jhi-register',
  templateUrl: './register.component.html',
  styleUrls: ['./register.style.scss']
})
export class RegisterComponent implements AfterViewInit {
  @ViewChild('login', { static: false })
  login?: ElementRef;

  doNotMatch = false;
  error = false;
  errorEmailExists = false;
  errorUserExists = false;
  success = false;
  ong = false;

  registerForm = this.fb.group({
    mobile: [
      '',
      [
        Validators.required,
        Validators.maxLength(16),
        Validators.pattern('^[0-9]*$'),
      ],
    ],
    company: [
      '',
      [
        Validators.required,
        Validators.maxLength(50)
       
      ],
    ],
    firstName: [
      '',
      [
        Validators.required,
        Validators.maxLength(50),
        Validators.pattern('^[a-zA-ZăĂîÎșȘțȚ-]*$'),
      ],
    ],
    lastName: [
      '',
      [
        Validators.required,
        Validators.maxLength(50),
        Validators.pattern('^[a-zA-ZăĂîÎșȘțȚ-]*$'),
      ],
    ],
    cui: [
      '',
      [
        Validators.required,
        Validators.maxLength(11),
        Validators.pattern('[A-Z]*[0-9]*'),
      ],
    ],
    email: ['', [Validators.required, Validators.maxLength(254), Validators.email]],
    password: ['', [Validators.required, Validators.minLength(6), Validators.maxLength(50), Validators.pattern('^(?=.*[0-9])(?=.*[a-z])(?=.*[A-Z]).{6,}$'),]],
    confirmPassword: ['', [Validators.required, Validators.minLength(6), Validators.maxLength(50), Validators.pattern('^(?=.*[0-9])(?=.*[a-z])(?=.*[A-Z]).{6,}$'),]],
  });

  constructor(
    private languageService: JhiLanguageService,
    private loginModalService: LoginModalService,
    private registerService: RegisterService,
    private fb: FormBuilder
  ) { }

  ngAfterViewInit(): void {
    if (this.login) {
      this.login.nativeElement.focus();
    }
  }

  get isValid(): boolean {
    let fields = ['firstName', 'lastName', 'mobile', 'email', 'password', 'confirmPassword'];

    if (this.ong) {
      fields = fields.concat(['company', 'cui'])
    }
    for (const field of fields) {
      const fieldControl = this.registerForm.get(field);
      if (fieldControl && fieldControl.invalid) {
        return false;
      }
    }
    return true;
  }

  register(): void {
    this.doNotMatch = false;
    this.error = false;
    this.success = false;
    this.errorEmailExists = false;
    this.errorUserExists = false;

    const password = this.registerForm.get(['password'])!.value;
    if (password !== this.registerForm.get(['confirmPassword'])!.value) {
      this.doNotMatch = true;
    } else {
      const cui = this.registerForm.get(['cui'])!.value;
      const mobile = this.registerForm.get(['mobile'])!.value;
      const company = this.registerForm.get(['company'])!.value;
      const firstName = this.registerForm.get(['firstName'])!.value;
      const lastName = this.registerForm.get(['lastName'])!.value;
      const email = this.registerForm.get(['email'])!.value;
      const langKey = this.languageService.getCurrentLanguage();

      this.registerService.save({ cui, mobile , company, firstName, lastName, email, password, langKey }).subscribe(
        () => this.success = true,
        (error) => this.processError(error)
      );
    }
  }

  openLogin(): void {
    this.loginModalService.open();
  }

  private processError(response: HttpErrorResponse): void {
    if (response.status === 400 && response.error.type === EMAIL_ALREADY_USED_TYPE) {
      this.errorEmailExists = true;
    } else {
      this.error = true;
    }
  }


}
