import { Component, OnInit } from "@angular/core";
import { FormBuilder, Validators } from "@angular/forms";
import { JhiLanguageService } from "ng-jhipster";

import { AccountService } from "app/core/auth/account.service";
import { Account } from "app/core/user/account.model";
import { LANGUAGES } from "app/core/language/language.constants";
import { SessionStorageService } from "ngx-webstorage";
import { LoginService } from "app/core/login/login.service";

@Component({
  selector: "jhi-settings",
  templateUrl: "./settings.component.html",
  styleUrls: ["./settings.style.scss"],
})
export class SettingsComponent implements OnInit {
  account!: Account;
  success = false;
  ongAccount = false;
  languages = LANGUAGES;
  settingsForm = this.fb.group({
    firstName: [
      undefined,
      [Validators.required, Validators.minLength(1), Validators.maxLength(50)],
    ],
    lastName: [
      undefined,
      [Validators.required, Validators.minLength(1), Validators.maxLength(50)],
    ],
    company: [undefined],
    cui: [undefined],
    email: [
      undefined,
      [
        Validators.required,
        Validators.minLength(5),
        Validators.maxLength(254),
        Validators.email,
      ],
    ],
    langKey: [undefined],
    mobile: [
      '',
      [
        Validators.required,
        Validators.maxLength(16),
        Validators.pattern('^[0-9]*$'),
      ],
    ],
  });

  constructor(
    private $sessionStorage: SessionStorageService,
    private accountService: AccountService,
    private fb: FormBuilder,
    private languageService: JhiLanguageService,
    private loginService: LoginService
  ) {}

  ngOnInit(): void {
    this.accountService.identity().subscribe((account) => {
      if (account) {
        this.settingsForm.setValue({
          firstName: account.firstName,
          lastName: account.lastName,
          company: account.company,
          cui: account.cui,
          email: account.email,
          langKey: account.langKey,
          mobile: account.mobile
        });

        this.account = account;
      }
    });
    if (this.account.company !== "" && this.account.cui !== "") {
      this.ongAccount = true;
    }
  }

  save(): void {
    this.success = false;
    this.account.firstName = this.settingsForm.get("firstName")!.value;
    this.account.lastName = this.settingsForm.get("lastName")!.value;
    this.account.company = this.settingsForm.get("company")!.value;
    this.account.cui = this.settingsForm.get("cui")!.value;
    this.account.email = this.settingsForm.get("email")!.value;
    this.account.langKey = this.settingsForm.get("langKey")!.value;
    this.account.mobile = this.settingsForm.get("mobile")!.value;


    this.accountService.save(this.account).subscribe(() => {
      this.success = true;
      this.accountService.authenticate(this.account);
      if (this.account.langKey !== this.languageService.getCurrentLanguage()) {
        this.languageService.changeLanguage(this.account.langKey);
      }

      this.$sessionStorage.store("account", this.account);
      this.loginService.user.next(this.account);
    });
  }
}
