import { NgModule } from '@angular/core';
import { RouterModule } from '@angular/router';
import { errorRoute } from './layouts/error/error.route';
import { navbarRoute } from './layouts/navbar/navbar.route';
import { DEBUG_INFO_ENABLED } from 'app/app.constants';
import { Authority } from 'app/shared/constants/authority.constants';

import { UserRouteAccessService } from 'app/core/auth/user-route-access-service';
import { CreateProductComponent } from './create-product/create-product.component';
import { ProductsComponent } from './products/products.component';
import { ProductDetailsComponent } from './product-details/product-details.component';
import { PostRequestsComponent } from './post-requests/post-requests.component';
import { OrderHistoryComponent } from './account/orders/order-history/order-history.component';
import { PostsComponent } from './account/orders/posts/posts.component';
import { OrdersComponent } from './account/orders/orders.component';
import { OngSettingsComponent } from './account/ong-settings/ong-settings.component';
import { OngProfileComponent } from './ong-profile/ong-profile.component';
import { OngSettingsGuard } from './account/ong-settings/ong-settings.guard'

const LAYOUT_ROUTES = [navbarRoute, ...errorRoute];

@NgModule({
  imports: [
    RouterModule.forRoot(
      [
        { path: 'create-product', component: CreateProductComponent },
        { path: 'edit-product/:id', component: CreateProductComponent },
        { path: 'products', component: ProductsComponent },
        { path: 'product-details/:id', component: ProductDetailsComponent },
        { path: 'ong-profile/:ongName', component: OngProfileComponent },
        { path: 'post-requests', component: PostRequestsComponent },
        { path: 'orders', component: OrdersComponent, children: [{path: 'history', component: OrderHistoryComponent},{path: 'posts', component: PostsComponent}]},
        { path: 'ong-settings', component: OngSettingsComponent, canActivate: [OngSettingsGuard] },
        {
          path: 'admin',
          data: {
            authorities: [Authority.ADMIN],
          },
          canActivate: [UserRouteAccessService],
          loadChildren: () => import('./admin/admin-routing.module').then(m => m.AdminRoutingModule),
        },
        {
          path: 'account',
          loadChildren: () => import('./account/account.module').then(m => m.AccountModule),
        },
        ...LAYOUT_ROUTES,
      ],
      { enableTracing: DEBUG_INFO_ENABLED }
    ),
  ],
  exports: [RouterModule],
})
export class PolihelpAppRoutingModule { }
