import { Injectable } from '@angular/core';
import { BehaviorSubject, Observable } from 'rxjs';
import { flatMap } from 'rxjs/operators';

import { Account } from 'app/core/user/account.model';
import { AccountService } from 'app/core/auth/account.service';
import { AuthServerProvider } from 'app/core/auth/auth-jwt.service';
import { Login } from './login.model';
import { User } from '../user/user.model';
import { SessionStorageService } from 'ngx-webstorage';

@Injectable({ providedIn: 'root' })



export class LoginService {
  
  user: BehaviorSubject<User | null>;

  constructor(private accountService: AccountService, private authServerProvider: AuthServerProvider, private $sessionStorage: SessionStorageService    ) {
    const currentUser = this.$sessionStorage.retrieve('account');
    this.user = new BehaviorSubject<User | null>(currentUser);
  }

  login(credentials: Login): Observable<Account | null> {
    return this.authServerProvider.login(credentials).pipe(flatMap(() => this.accountService.identity(true)));
  }

  logout(): void {
    this.$sessionStorage.clear('account');
    this.user.next(null);
    this.authServerProvider.logout().subscribe(null, null, () => this.accountService.authenticate(null));
  }
}
