import { Component, OnInit, ViewChild } from "@angular/core";
import { CreateProductService } from "./create-product.service";
import { FormBuilder, Validators } from "@angular/forms";
import { ActivatedRoute } from "@angular/router";
import { Router } from "@angular/router";
import { UploadImageComponent } from "app/upload-image/upload-image.component";
import { CategoryItems } from "app/products/products.service";
import { SessionStorageService } from "ngx-webstorage";
import { Product } from "app/core/user/product.model";
@Component({
  selector: "jhi-create-product",
  templateUrl: "./create-product.component.html",
  styleUrls: ["./create-product.component.scss"],
})
export class CreateProductComponent implements OnInit {

  @ViewChild("uploader", { static: false }) uploader?: UploadImageComponent;

  success = false;
  error = false;
  company = false;
  donation = false;
  UploadLabel = "Upload Images";
  maxUploadNr = 3;

  //  enums
  categoryItemsEnum: typeof CategoryItems = CategoryItems;

  productForm = this.fb.group({
    category: ["", Validators.required],
    claimedByOng: ["", [Validators.required]],
    title: [
      "",
      [Validators.required, Validators.maxLength(1500)],
    ],
    price: [0, [Validators.pattern("^[0-9]*$")]],
    quantity: [1, [Validators.max(1000), Validators.min(1)]],
    description: [
      "",
      [Validators.required, Validators.minLength(10), Validators.maxLength(1500)],
    ],
    deliveryDetails: ["", [Validators.maxLength(1500)]],

  });

  currentProduct?: Product;
  currentPicturesList?: string[] = [];

  constructor(
    private createProductService: CreateProductService,
    private fb: FormBuilder,
    private router: ActivatedRoute,
    private route: Router,
    public $sessionStorage: SessionStorageService
  ) {
    this.donation = false;
  }

  ngOnInit(): void {
    if (this.route.url.includes("edit")) {
      this.createProductService
        .getProduct(this.router.snapshot.params.id)
        .subscribe((data) => {
          this.currentProduct = data;
          if (this.currentProduct.productType === "DONATION") {
            this.donation = true;
          }
          this.productForm.setValue({
            category: this.currentProduct.category,
            claimedByOng: this.currentProduct.claimedByOng,
            title: this.currentProduct.title,
            price: this.currentProduct.price,
            quantity: this.currentProduct.quantity,
            description: this.currentProduct.description,
            deliveryDetails: this.currentProduct.deliveryDetails,
          });
          if (this.currentProduct.picturePath) {

            if (this.currentProduct.picturePath.endsWith(',')) {
              this.currentPicturesList = this.currentProduct.picturePath?.split(',', (this.currentProduct.picturePath.split(',').length - 1))
            } else {
              this.currentPicturesList = this.currentProduct.picturePath?.split(',', (this.currentProduct.picturePath.split(',').length))
            }

          }
        });
    }

    const donation = this.router.snapshot.queryParams.donation;

    if (donation) {
      this.donation = donation === "true" ? true : false;
    }
  }

  get isValid(): boolean {
    const fields = ["title", "description", "category", "deliveryDetails"];

    for (const field of fields) {
      const fieldControl = this.productForm.get(field);
      if (fieldControl && fieldControl.invalid) {
        return false;
      }
    }
    return true;
  }

  async submitProduct(): Promise<void> {
    const claimedByOng = this.productForm.get(["claimedByOng"])!.value;
    const title = this.productForm.get(["title"])!.value;
    const description = this.productForm.get(["description"])!.value;
    const category = this.productForm.get(["category"])!.value;
    const price = this.productForm.get(["price"])!.value;
    const quantity = Number(this.productForm.get(["quantity"])!.value);
    const deliveryDetails = this.productForm.get(["deliveryDetails"])!.value;
    let picturePath = await this.uploader?.upload();
    const currentPicturePath = this.currentPicturesList?.join();
    const dateOfPost = new Date();
    const status = "AVAILABLE";
    let productType = "";

    if (this.route.url.includes("edit")) {
      if (picturePath) {
        picturePath = picturePath + currentPicturePath;
        if (!picturePath.endsWith(',')) {
          picturePath = picturePath + ",";
        }
      } else {
        picturePath = currentPicturePath;
        if (!picturePath!.endsWith(',')) {
          picturePath = picturePath + ",";
        }
      }
    }

    if (this.donation === true) {
      productType = "DONATION";
    } else {
      productType = "SELL";
    }

    if (this.route.url.includes("edit")) {
      this.createProductService
        .editProduct(this.router.snapshot.params.id, {
          dateOfPost,
          productType,
          status,
          category,
          claimedByOng,
          deliveryDetails,
          description,
          price,
          quantity,
          title,
          picturePath,
        })
        .subscribe(() => {
          this.success = true;
        });
    } else {
      this.createProductService
        .save({
          dateOfPost,
          productType,
          status,
          category,
          claimedByOng,
          deliveryDetails,
          description,
          price,
          quantity,
          title,
          picturePath,
        })
        .subscribe(() => {
          this.success = true;
        });
    }
  }

  openProducts(): void {
    this.route.navigate(["/products"]);
  }

  goTo(page: string): void {
    this.route.navigate([page]);
  }

  removePicture(index: number): void{
    this.currentPicturesList = this.currentPicturesList?.slice(0, index). concat(this.currentPicturesList.slice(index+1))
  }
}
