import { Component, OnInit, OnDestroy, ViewChild } from '@angular/core';
import { Subscription } from 'rxjs';
import { LoginModalService } from 'app/core/login/login-modal.service';
import { AccountService } from 'app/core/auth/account.service';
import { Account } from 'app/core/user/account.model';
import { Router } from '@angular/router';
import { LocalStorageService, SessionStorageService } from 'ngx-webstorage';
import { NgbModal, NgbCarousel } from '@ng-bootstrap/ng-bootstrap';
import { HomeService } from "./home.service"
import { OngSettings } from 'app/account/ong-settings/ong-settings.model';
import { OngProject } from 'app/account/ong-settings/ong-project.model'

@Component({
  selector: 'jhi-home',
  templateUrl: './home.component.html',
  styleUrls: ['home.scss'],
})
export class HomeComponent implements OnInit, OnDestroy {

  account: Account | null = null;
  authSubscription?: Subscription;
  @ViewChild('ngcarousel', { static: true })
  ngCarousel!: NgbCarousel;
  ongList?: OngSettings[];
  ongListMatrix?: OngSettings[][];

  projectsCarousel!: OngProject[];
  token = this.$sessionStorage.retrieve('authenticationToken');

  // variable for img path (show img`s on localhost)
  imgHost = "http://192.168.1.34/";


  constructor(private accountService: AccountService, 
    private loginModalService: LoginModalService, 
    private router: Router, 
    private $localStorage: LocalStorageService, 
    private $sessionStorage: SessionStorageService, 
    private modalService: NgbModal,
    private homeService: HomeService) {
     }

  ngOnInit(): void {

    this.authSubscription = this.accountService.getAuthenticationState().subscribe(account => (this.account = account));
    const projectsParams = this.homeService.getCountParams(1000);
    const ongParams = this.homeService.getCountParams(1000);
    this.homeService.getAllOng(ongParams).subscribe(
      data => {
        
        this.ongList = data;
        this.ongListMatrix = []
        let row = [];
        
        
        for(let i = 0; i < data.length; i++) {
            row.push(data[i])
              if (row.length/3 === 1){
                this.ongListMatrix.push(row)
                row = []
                }
              else if (i >= data.length - 2)
                this.ongListMatrix.push(row)
        } 

          // let i = 0;

          // while(i < data.length) {
          //   row.push(data[i]);
          //   if(row.length === 3) {
          //     this.ongListMatrix.push(row);
          //     row = [];
          //   }
          //   i++;
          // }

          // if(row.length > 0) {
          //   this.ongListMatrix.push(row);
          // }
      });

    this.homeService.getProjects(projectsParams).subscribe(
      (projects) => {this.projectsCarousel = projects});
    } 

  ngOnDestroy(): void {
    if (this.authSubscription) {
      this.authSubscription.unsubscribe();
    }
  }

  isAuthenticated(): boolean {
    return this.accountService.isAuthenticated();
  }

  login(): void {
    this.loginModalService.open();
  }

  register(): void {
    this.router.navigate(['/account/register']);
  }

  getToken(): string {
    return this.$localStorage.retrieve('authenticationToken') || this.$sessionStorage.retrieve('authenticationToken') || '';
  }

  openVerticallyCentered(content: any): void {
    this.modalService.open(content, { centered: true });
  }

  // Move to previous slide
  getToPrev(): void {
    this.ngCarousel.prev();
  }

  // Move to next slide
  goToNext(): void {
    this.ngCarousel.next();
  }
}