import { Component, OnInit } from '@angular/core';
import { NgbModal } from '@ng-bootstrap/ng-bootstrap';
import { OngSettingsService } from 'app/account/ong-settings/ong-settings.service'
import { OngSettings } from 'app/account/ong-settings/ong-settings.model';
import { Account } from 'app/core/user/account.model';
import { ToastrService } from "ngx-toastr";
import { AccountService } from 'app/core/auth/account.service';
import { SessionStorageService } from 'ngx-webstorage';

@Component({
  selector: "jhi-ong-profile",
  templateUrl: "./ong-profile.component.html",
  styleUrls: ["./ong-profile.component.scss"],
})
export class OngProfileComponent implements OnInit {
  ongName = "";
  ongProfile: OngSettings = {};
  subscribed = false;
  ongLogo = '';
  ongCover = '';
  ongSocialLink: string[ ] = [ ];
  ongLink = '';
  ongNeeds = '';
  account!: Account;
  accountMail = '';
  token = this.$sessionStorage.retrieve('authenticationToken');

  constructor(
    private modalService: NgbModal,
    public ongSettingsService: OngSettingsService,
    private toastr: ToastrService,
    private accountService : AccountService,
    private $sessionStorage: SessionStorageService
  ) {}

  ngOnInit(): void {
    this.ongName = window.location.pathname;
    this.ongName = this.ongName.replace("/ong-profile/", "");

    this.ongSettingsService.getOng(this.ongName).subscribe((ongData) => {
      this.ongProfile = ongData;
      this.ongLogo = this.ongProfile.ongLogoPath!.split(",")[0];
      this.ongCover = this.ongProfile.ongCoverPath!.split(",")[0];
      this.ongLink = this.ongProfile.ongLink!;
      this.ongSocialLink = this.ongProfile.socialLinks!;
      this.ongNeeds = this.ongProfile.ongNeeds!;
    });

    console.error(this.ongLink)

    // if user is not logged-in skip this request
    if (this.token != null){
    this.ongSettingsService
      .checkSubscription(this.ongName)
      .subscribe((response) => {
        this.subscribed = response;
      }
    )};

    if (this.token != null){  
    this.accountService.identity().subscribe(account => {
      this.account = account!,
      this.accountMail = this.account.email;
      }
    )};
  }

  openVerticallyCentered(content: any): void {
    this.modalService.open(content, { centered: true });
  }

  subscribe(): void {
    this.ongSettingsService
      .emailSubscribe(this.ongProfile.user?.company!)
      .subscribe();
      this.subscribed = !this.subscribed;
      this.toastr.success("You've been subscribed");
  }

  unsubscribe(): void {
    this.ongSettingsService
      .emailUnsubscribe(this.ongProfile.user?.company!)
      .subscribe();
      this.subscribed = !this.subscribed;
      this.toastr.info("You've been unsubscribed");
  }

  iconSelect(X: string) {
    if (X.includes("facebook"))
      return "../../content/images/social/facebook.png";
    else if (X.includes("twitter"))
      return "../../content/images/social/twitter.png";
    else if (X.includes("youtube"))
      return "../../content/images/social/youtube.png";
    else if (X.includes("instagram"))
      return "../../content/images/social/instagram.png";
    else return "../../content/images/social/generic.png";
  }

  linkVerify(link: string) {
    let result = ""

    if(link.includes("http")) {

      return link;

    } else {
      
      result = 'https://' + link
      return result
    }
  }

  goBack(): void {
    window.history.back();
  }
}
