import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { Product } from 'app/core/user/product.model';
import { PostRequestsService } from './post-requests.service'

@Component({
  selector: 'jhi-post-requests',
  templateUrl: './post-requests.component.html',
  styleUrls: ['./post-requests.component.scss']
})
export class PostRequestsComponent implements OnInit {
  searchText!: string;
  columnLabels: string[] = ['Id',
    'Date',
    'Type',
    'Category',
    'Title',
    'Price',
    'Quantity',
    'Description',
    'Picture',
    'Status',
    'Claimed By Ong',
    'Delivery']
  products: Product[] = [];
  reverseProducts: Product[] = [];
  itemsPerPage = 15;
  page = 1;
  predicate!: string;
  ascending!: boolean;
  totalItems = 0;
  $sessionStorage: any;
  id!: Number;


  constructor(private postRequestsService: PostRequestsService, private router: Router, private activatedRoute: ActivatedRoute) {
    this.postRequestsService.getProducts().subscribe(data => {
      this.products = data;
      this.reverseProducts = this.products.slice().reverse();
    })
  }
  
  ngOnInit(): void {
   
  }

  transition(): void {
    this.router.navigate(['./'], {
      relativeTo: this.activatedRoute.parent,
      queryParams: {
        page: this.page,
        sort: this.predicate + ',' + (this.ascending ? 'asc' : 'desc'),
      },
    });
  }


  selectPage(pageNr: number): any {
    this.page = pageNr;
    this.$sessionStorage.store('pageNr', this.page);
  }

  activatePost(id: number, product: Product): void {
    this.postRequestsService.activatePost(id, product).subscribe(
      () => {
        this.postRequestsService.getProducts().subscribe(data => {
          this.products = data;
          this.reverseProducts = this.products.slice().reverse();
        })
      }
    )
  }

  declinePost(id: number): void {
    this.postRequestsService.declinePost(id).subscribe(
      () => {
        this.postRequestsService.getProducts().subscribe(data => {
          this.products = data;
          this.reverseProducts = this.products.slice().reverse();
        })
      }
    )
  }

}
