import { Component, OnInit, ViewChild } from "@angular/core";
import { ActivatedRoute, Router } from "@angular/router";
import { Product } from "app/core/user/product.model";
import { Comment } from "./comment.model";
import { ProductDetailsService } from "app/product-details/product-details.service";
import { User } from "app/core/user/user.model";
import { FormBuilder, FormGroup, Validators } from "@angular/forms";
import { CarouselComponent } from "angular-responsive-carousel";
import { SessionStorageService } from "ngx-webstorage";

@Component({
  selector: "jhi-product-details",
  templateUrl: "./product-details.component.html",
  styleUrls: ["./product-details.component.scss"],
})
export class ProductDetailsComponent implements OnInit {
  @ViewChild("carousel", { static: true }) carousel:
    | CarouselComponent
    | undefined;
    
  zoom = 12;
  

  tableSwitch = false;
  noPictures = false;
  normalAccount = false;
  ongAccount = false;
  contact = false;
  edit = false;

  itemsPerPage = 5;
  page = 1;
  selectedComment!: any;
  id!: Number;
  product: Product = {};
  comments: Comment[] = [];
  reverseComments: Comment[] = [];
  pictureList: string[] | undefined = [];
  user: User = {};
  commentForm = this.fb.group({
    comment: ["", Validators.required],
  });
  editForm = this.fb.group({
    editComm: ["", Validators.required],
  });
  

  quantityForm = this.fb.group({
    quantity: []
  });

  previousUrl!: string;
  contactMobile: string | undefined = "";
  contactEmail: string | undefined = "";
  accountEmail: string | undefined = "";

  constructor(
    private route: Router,
    private activatedRoute: ActivatedRoute,
    private productDetailsService: ProductDetailsService,
    private fb: FormBuilder,
    private $sessionStorage : SessionStorageService,
  ) {}

  submitComment(): Comment[] {
    const content = this.commentForm.get(["comment"])!.value;

    if (content !== null) {
      this.productDetailsService
        .saveComment(this.id, { content })
        .subscribe(() => {
          this.commentForm.reset();
          this.productDetailsService.getComments(this.id).subscribe((data) => {
            this.comments = data;
            this.reverseComments = this.comments.slice().reverse();
          });
        });
    }
    return this.comments;
  }

  editComment(comId: any): void {
    const content = this.editForm.get(["editComm"])!.value;

    if (content !== null && content !== "") {
      this.productDetailsService
        .editComment(this.id, comId, { content })
        .subscribe(() => {
          this.edit = !this.edit;
          this.editForm.reset();
          this.productDetailsService.getComments(this.id).subscribe((data) => {
            this.comments = data;
            this.reverseComments = this.comments.slice().reverse();
          });
        });
    }
  }

  deleteComment(comId: any): void {
    this.productDetailsService.deleteComment(this.id, comId).subscribe(() => {
      this.productDetailsService.getComments(this.id).subscribe((data) => {
        this.comments = data;
        this.reverseComments = this.comments.slice().reverse();
      });
    });
  }
  get isValid(): boolean {
    const fields = ["content"];

    for (const field of fields) {
      const fieldControl = this.commentForm.get(field);
      if (fieldControl && fieldControl.invalid) {
        return false;
      }
    }
    return true;
  }

  claimProduct(): void {
    const quantity = this.quantityForm?.get('quantity')!.value;

    this.productDetailsService
      .claimProduct(this.id, Number(quantity))
      .subscribe(() => {
        this.route.navigate(["orders", "history"]);
      });
  }

  quantityArray(n: any): any[] {
    return Array(n);
  }

  ngOnInit(): void {
    this.id = Number(this.activatedRoute.snapshot.paramMap.get("id"));
    this.productDetailsService.getProduct(this.id).subscribe((data) => {
      
      this.product = data;
      this.contactMobile = this.product.user?.userDetails?.mobile
      this.contactEmail = this.product.user?.email
      this.product.thumbnail = this.product.picturePath?.split(",")[0];

      this.pictureList = this.product.picturePath?.split(
        ",",
        this.product.picturePath?.split(",").length - 1
      );

      for (let i = 0; i < this.pictureList!.length; i++) {
        this.productDetailsService.getImage(this.pictureList![i]);
      }
      
      this.carousel?.onWindowResize(null);

      
      this.quantityForm = this.fb.group({
        quantity: [
          1,
          [Validators.required, Validators.max(this.product.quantity as number)],
        ],
      });
    });

    this.productDetailsService.getComments(this.id).subscribe((data) => {
      this.comments = data;
      this.reverseComments = this.comments.slice().reverse();
    });

    this.productDetailsService.getUser().subscribe((data) => {
      this.user = data;
      this.accountEmail = this.user.email;
      if (this.user.cui !== "") {
        this.ongAccount = true;
      } else {
        this.normalAccount = true;
      }
    });
  }

  switchEdit(currentCommentId: Comment): void {
    this.selectedComment = currentCommentId.id;
    this.edit = !this.edit;
    this.editForm.controls["editComm"].setValue(currentCommentId.content);
  }

  goTo(): void {
    window.history.back();
  }

  switchContact(): void {
    this.contact = !this.contact;
  }

  selectPage(pageNr: number): any {
    this.page = pageNr;
    this.$sessionStorage.store("pageNr", this.page);
  }

  get isValidQuantity(): boolean {
    const fields = ["quantity"];

    for (const field of fields) {
      const fieldControl = this.quantityForm?.get(field);
      if (fieldControl && fieldControl.invalid) {
        return false;
      }
    }
    return true;
  }


}
