import { Component, OnInit } from '@angular/core';
import { Router } from '@angular/router';
import { Product } from 'app/core/user/product.model';
import { ProductService } from './products.service';
import { SessionStorageService } from 'ngx-webstorage';
import { CategoryItems } from './products.service';
import { ProductType } from './products.service';
import { ProductsFilterPipe } from './products-filter.pipe';


@Component({
  selector: "jhi-products",
  templateUrl: "./products.component.html",
  styleUrls: ["./products.style.scss"],
})
export class ProductsComponent implements OnInit {

  searchText!: string;

  /** pagination and product fetch*/
  itemsPerPage = 5;
  page = 1;
  pictureList: string[] | undefined = [];
  currentProducts: Product[] = [];
  filteredProducts: Product[] = [];
  selectedCategory = "";
  claimedByOng = "";
  productType = "";
  filterMetadata = { count: 0 };

  // add this to image src to display picture
  imgHost = "http://192.168.1.34/"


  //  enums
  categoryItemsEnum: typeof CategoryItems = CategoryItems
  productTypeEnum: typeof ProductType = ProductType
  companyName?: string;

  constructor(private router: Router, private productService: ProductService, public $sessionStorage: SessionStorageService) { }

  ngOnInit(): void {
    
    this.initContext();
    
    const params = this.productService.getQueryParams(this.selectedCategory, 0, 10, this.claimedByOng, "", this.productType);

    
    this.productService.getProduct(params).subscribe(data => {
      this.currentProducts = data;
      this.filteredProducts = data; // when component is initilize display all products
      for (let i = 0; i < this.filteredProducts.length; i++) {
        this.filteredProducts[i].thumbnail = this.filteredProducts[i].picturePath?.split(',')[0];
      }
    });
  } 

  // value of the category is set using double binding
  setCategory(): any {
    this.$sessionStorage.store('catFilter', this.selectedCategory);
    this.updateProducts();
    this.filteredProducts = this.currentProducts.filter(m => m["category"] === name);
    return this.filteredProducts;
  }

  setOng(ong: string): any {
    this.claimedByOng = ong;
    this.$sessionStorage.store('ongFilter', this.claimedByOng);
    this.updateProducts();
  }

  setType(type: string): any {
    this.productType = type;
    this.$sessionStorage.store('typeFilter', this.productType);
    this.updateProducts();
  }

  updateProducts(): void {
    const params = this.productService.getQueryParams(this.selectedCategory, 0, 10, this.claimedByOng, "", this.productType);
    this.productService.getProduct(params).subscribe(fetchedProducts => {
      this.filteredProducts = fetchedProducts;
      for (let i = 0; i < this.filteredProducts.length; i++) {
        this.filteredProducts[i].thumbnail = this.filteredProducts[i].picturePath?.split(',')[0];
      }
    });
  }

  register(): void {
    this.router.navigate(["/account/register"]);
  }

  goToProduct(donation: boolean): void {
    const company = this.$sessionStorage.retrieve('account').company!
    this.router.navigate(["/create-product"], { queryParams: { donation, company } });
  }

  goTo(page: string): void {
    this.router.navigate([page]);
  }

  selectCat(name: string): any {
    this.filteredProducts = this.currentProducts;
    if (name === "--all categories--") {
      return this.filteredProducts;
    }

    this.filteredProducts = this.currentProducts.filter(m => m["category"] === name);
    return this.filteredProducts;
  }

  selectOng(ong: string): any {
    this.claimedByOng = ong
    const p = this.productService.getQueryParams(this.selectedCategory, 0, 10, this.claimedByOng, "", this.productType);
    this.productService.getProduct(p).subscribe(someData => {
      this.filteredProducts = someData;
    });
  }

  selectPage(pageNr: number): any {
    this.page = pageNr;
    this.$sessionStorage.store('pageNr', this.page);
  }

  initContext(): void {
    this.page = this.$sessionStorage.retrieve('pageNr') === null ? 1 : this.$sessionStorage.retrieve('pageNr');
    this.selectedCategory = this.$sessionStorage.retrieve('catFilter') === null ? "" : this.$sessionStorage.retrieve('catFilter');
    this.claimedByOng = this.$sessionStorage.retrieve('ongFilter') === null ? "" : this.$sessionStorage.retrieve('ongFilter');
    this.productType = this.$sessionStorage.retrieve('typeFilter') === null ? "" : this.$sessionStorage.retrieve('typeFilter');
  }

  prodCat(X: string): any {
    if (X === 'DONATION')
      return 'search.typeDonation';
    else return 'search.typeSell'
  }

}