import { Injectable } from '@angular/core';
import { SERVER_API_URL } from 'app/app.constants';
import { HttpClient, HttpParams } from '@angular/common/http';
import { Observable } from 'rxjs';
import { Product } from 'app/core/user/product.model';

export enum CategoryItems {
    ELECTRONICS = "ELECTRONICS",
    FOOD = "FOOD",
    CLOTHES = "CLOTHES",
    OTHERS = "OTHERS"
}

export enum ProductStatus {
    AVAILABLE = "AVAILABLE",
    OUTOFSTOCK = "Out of stock",
    SOLD = "SOLD",
    PENDING = "PENDING"
}

export enum ProductType{
    DONATION = "DONATION",
    SELL = "SELL"
}

@Injectable({
    providedIn: "root"
})
export class ProductService {
    public resourceUrl = SERVER_API_URL + 'api/product';

    constructor(private http: HttpClient) { }

    addProduct(product: string): Observable<string> {
        return this.http.post<string>(this.resourceUrl, product);
    }

    getProduct(params: HttpParams): Observable<Product[]> {
        return this.http.get<Product[]>(this.resourceUrl, {
            params
        });
    }

    getQueryParams(category: string, indexEnd: number, indexStart: number, claimedByOng: string, status: string, type: string): HttpParams {
        const params = new HttpParams().set("category", category)
            .set("indexStart", indexStart.toString())
            .set("indexEnd", indexEnd.toString())
            .set("claimedByOng", claimedByOng.toString())
            .set("status", ProductStatus.AVAILABLE)
            .set("type", type);
        return params;
    }
}

