import { Component, AfterViewInit, ElementRef, ViewChild } from "@angular/core";
import { FormBuilder } from "@angular/forms";
import { NgbActiveModal } from "@ng-bootstrap/ng-bootstrap";
import { Router } from "@angular/router";
import { LoginService } from "app/core/login/login.service";
import { AccountService } from 'app/core/auth/account.service';
import { SessionStorageService } from 'ngx-webstorage';

@Component({
  selector: "jhi-login-modal",
  templateUrl: "./login.component.html",
  styleUrls: ["login.component.scss"],
})
export class LoginModalComponent implements AfterViewInit {
  @ViewChild("email", { static: false })
  email?: ElementRef;

  authenticationError = false;
  show: boolean;

  loginForm = this.fb.group({
    email: [""],
    password: [""],
    rememberMe: [false],
  });

  constructor(
    private loginService: LoginService,
    private router: Router,
    public activeModal: NgbActiveModal,
    private fb: FormBuilder,
    private accountService: AccountService,
    private $sessionStorage: SessionStorageService
  ) 
  {
    this.show = false;
  }

  password(): void {
    this.show = !this.show;
  }

  ngAfterViewInit(): void {
    if (this.email) {
      this.email.nativeElement.focus();
    }
  }

  login(): void {
    this.loginService
      .login({
        username: this.loginForm.get("email")!.value,
        password: this.loginForm.get("password")!.value,
        rememberMe: this.loginForm.get("rememberMe")!.value,
      })
      .subscribe(
        () => {
          this.accountService.fetch().subscribe(
            (account) => {
              this.$sessionStorage.store('account', account);
              this.loginService.user.next(account);
            }
          )
          this.authenticationError = false;
          this.activeModal.close();

          this.router.navigate(["/account/products"]);
        },
        () => (this.authenticationError = true)
      );
  }

  forget(): void {
    this.activeModal.dismiss("to state reset password");
    this.router.navigate(["account/reset/request"])
  }

  register(): void {
    this.activeModal.dismiss("to state register");
    this.router.navigate(["/account/register"]);
  }
}
