import { Component, Input, OnInit } from "@angular/core";
import { UploadPictureService } from "./upload-picture.service";

@Component({
  selector: "jhi-upload-image",
  templateUrl: "./upload-image.component.html",
  styleUrls: ["./upload-image.component.scss"],
})
export class UploadImageComponent implements OnInit {
  @Input() id = "";
  @Input() buttonLabelKey! : string;
  @Input() MAX_PICTURE_NR_FOR_UPLOAD = 3;


  selectedFiles!: FileList;
  fileNames: string[] = [];

  currentFileUpload!: File | null;
  isInputValid = true;
  urls = new Array<string>();
  changeImage = false;
  lengthError = false;
  sizeError = false;

  MAX_FILE_SIZE = 3000000; // 3MB

  constructor(private uploadService: UploadPictureService) {}
  ngOnInit(): void {}

  async upload(): Promise<string> {
    let paths = "";
    if (!this.selectedFiles) {
      // this.isInputValid = false;
    } else {
      for (let i = 0; i < this.selectedFiles.length; i++) {
        if (this.selectedFiles.item(i) != null)
          this.currentFileUpload = this.selectedFiles.item(i);
        const data = await this.uploadService.pushFileToStorage(
          this.currentFileUpload
        );
        paths += data.filename + ",";
      }
    }
    return paths;
  }

  checkIfFilesAreValid(fileList: FileList): boolean {
    if (fileList.length > this.MAX_PICTURE_NR_FOR_UPLOAD) {
      return false;
    }

    for (let i = 0; i < fileList.length; i++) {
      if (fileList[i].size > this.MAX_FILE_SIZE) {
        return false;
      }
    }
    return true;
  }

  detectFiles(event: any): void {
    this.urls = [];
    this.fileNames = [];
    const files = event.target.files;
    this.selectedFiles = files;
    this.isInputValid = this.checkIfFilesAreValid(files);

    if (this.isInputValid) {
      for (const file of files) {
        this.fileNames.push(file.name);
        const reader = new FileReader();
        reader.onload = (e: any) => {
          this.urls.push(e.target.result);
        };
        reader.readAsDataURL(file);
      }
    }
  }

  removeSelectedFile(index: number): void {
    this.fileNames.splice(index, 1);
    this.urls.splice(index, 1);
  }
}
